==> ejc-bfyjerp-impl-3.0.0-20250225.013449-149-sources.jar: com/ejianc/business/oa/bean/PayrollDetailEntity.java <==
package com.ejianc.business.oa.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 人力行政-工资表子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_oa_employee_payroll_detail")
public class PayrollDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="payroll_id")
    private Long payrollId; // 工资表主表id
    @TableField(value="dept_id")
    private Long deptId; // 部门ID
    @TableField(value="dept_name")
    private String deptName; // 部门
    @TableField(value="post_id")
    private Long postId; // 岗位ID
    @TableField(value="post_name")
    private String postName; // 岗位
    @TableField(value="source_id")
    private Long sourceId; // 来源id
    @TableField(value="employee_id")
    private Long employeeId; // 员工名称
    @TableField(value="name")
    private String name; // 姓名
    @TableField(value="id_card")
    private String idCard; // 身份证号
    @TableField(value="salary_time")
    private BigDecimal salaryTime; // 计薪工时
    @TableField(value="basic_salary")
    private BigDecimal basicSalary; // 基本薪资
    @TableField(value="post_salary")
    private BigDecimal postSalary; // 岗位薪资
    @TableField(value="level_salary")
    private BigDecimal levelSalary; // 层级薪资
    @TableField(value="educated_salary")
    private BigDecimal educatedSalary; // 学历津贴
    @TableField(value="sport_salary")
    private BigDecimal sportSalary; // 交通补助
    @TableField(value="year_salary")
    private BigDecimal yearSalary; // 司龄津贴
    @TableField(value="attendance_deduct")
    private BigDecimal attendanceDeduct; // 考勤扣款
    @TableField(value="other_pay_mny")
    private BigDecimal otherPayMny; // 其他应付款
    @TableField(value="other_deduct_mny")
    private BigDecimal otherDeductMny; // 其他扣款
    @TableField(value="salary_mny")
    private BigDecimal salaryMny; // 应发工资
    @TableField(value="actual_salary_mny")
    private BigDecimal actualSalaryMny; // 实发工资
    @TableField(value="endownment_person_percent")
    private BigDecimal endownmentPersonPercent; // 养老保险
    @TableField(value="unemployee_person_mny")
    private BigDecimal unemployeePersonMny; // 失业保险
    @TableField(value="base_medical_person_mny")
    private BigDecimal baseMedicalPersonMny; // 基本医疗
    @TableField(value="rank")
    private Integer rank; // 职级
    @TableField(value="rank_name")
    private String rankName; // 职级
    @TableField(value="into_date")
    private Date intoDate; // 入职日期
    @TableField(value="formal_date")
    private Date formalDate; // 转正日期
    @TableField(value="payroll_date")
    private Date payrollDate; // 工资单日期
    @TableField(value="detail_memo")
    private String detailMemo; // 备注
    
    
    

    public Long getPayrollId() {
        return payrollId;
    }

    public void setPayrollId(Long payrollId) {
        this.payrollId = payrollId;
    }
    public Long getDeptId() {
        return deptId;
    }

    public void setDeptId(Long deptId) {
        this.deptId = deptId;
    }
    public String getDeptName() {
        return deptName;
    }

    public void setDeptName(String deptName) {
        this.deptName = deptName;
    }
    public Long getPostId() {
        return postId;
    }

    public void setPostId(Long postId) {
        this.postId = postId;
    }
    public String getPostName() {
        return postName;
    }

    public void setPostName(String postName) {
        this.postName = postName;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public String getIdCard() {
        return idCard;
    }

    public void setIdCard(String idCard) {
        this.idCard = idCard;
    }
    public BigDecimal getSalaryTime() {
        return salaryTime;
    }

    public void setSalaryTime(BigDecimal salaryTime) {
        this.salaryTime = salaryTime;
    }
    public BigDecimal getBasicSalary() {
        return basicSalary;
    }

    public void setBasicSalary(BigDecimal basicSalary) {
        this.basicSalary = basicSalary;
    }
    public BigDecimal getPostSalary() {
        return postSalary;
    }

    public void setPostSalary(BigDecimal postSalary) {
        this.postSalary = postSalary;
    }
    public BigDecimal getLevelSalary() {
        return levelSalary;
    }

    public void setLevelSalary(BigDecimal levelSalary) {
        this.levelSalary = levelSalary;
    }
    public BigDecimal getEducatedSalary() {
        return educatedSalary;
    }

    public void setEducatedSalary(BigDecimal educatedSalary) {
        this.educatedSalary = educatedSalary;
    }
    public BigDecimal getSportSalary() {
        return sportSalary;
    }

    public void setSportSalary(BigDecimal sportSalary) {
        this.sportSalary = sportSalary;
    }
    public BigDecimal getYearSalary() {
        return yearSalary;
    }

    public void setYearSalary(BigDecimal yearSalary) {
        this.yearSalary = yearSalary;
    }
    public BigDecimal getAttendanceDeduct() {
        return attendanceDeduct;
    }

    public void setAttendanceDeduct(BigDecimal attendanceDeduct) {
        this.attendanceDeduct = attendanceDeduct;
    }
    public BigDecimal getOtherPayMny() {
        return otherPayMny;
    }

    public void setOtherPayMny(BigDecimal otherPayMny) {
        this.otherPayMny = otherPayMny;
    }
    public BigDecimal getOtherDeductMny() {
        return otherDeductMny;
    }

    public void setOtherDeductMny(BigDecimal otherDeductMny) {
        this.otherDeductMny = otherDeductMny;
    }
    public BigDecimal getSalaryMny() {
        return salaryMny;
    }

    public void setSalaryMny(BigDecimal salaryMny) {
        this.salaryMny = salaryMny;
    }
    public BigDecimal getActualSalaryMny() {
        return actualSalaryMny;
    }

    public void setActualSalaryMny(BigDecimal actualSalaryMny) {
        this.actualSalaryMny = actualSalaryMny;
    }
    public BigDecimal getEndownmentPersonPercent() {
        return endownmentPersonPercent;
    }

    public void setEndownmentPersonPercent(BigDecimal endownmentPersonPercent) {
        this.endownmentPersonPercent = endownmentPersonPercent;
    }
    public BigDecimal getUnemployeePersonMny() {
        return unemployeePersonMny;
    }

    public void setUnemployeePersonMny(BigDecimal unemployeePersonMny) {
        this.unemployeePersonMny = unemployeePersonMny;
    }
    public BigDecimal getBaseMedicalPersonMny() {
        return baseMedicalPersonMny;
    }

    public void setBaseMedicalPersonMny(BigDecimal baseMedicalPersonMny) {
        this.baseMedicalPersonMny = baseMedicalPersonMny;
    }
    public Integer getRank() {
        return rank;
    }

    public void setRank(Integer rank) {
        this.rank = rank;
    }
    public String getRankName() {
        return rankName;
    }

    public void setRankName(String rankName) {
        this.rankName = rankName;
    }
    public Date getIntoDate() {
        return intoDate;
    }

    public void setIntoDate(Date intoDate) {
        this.intoDate = intoDate;
    }
    public Date getFormalDate() {
        return formalDate;
    }

    public void setFormalDate(Date formalDate) {
        this.formalDate = formalDate;
    }
    public Date getPayrollDate() {
        return payrollDate;
    }

    public void setPayrollDate(Date payrollDate) {
        this.payrollDate = payrollDate;
    }
    public String getDetailMemo() {
        return detailMemo;
    }

    public void setDetailMemo(String detailMemo) {
        this.detailMemo = detailMemo;
    }
    
}

==> ejc-bfyjerp-impl-3.0.0-20250813.072903-273-sources.jar: com/ejianc/business/oa/bean/PayrollDetailEntity.java <==
package com.ejianc.business.oa.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 人力行政-工资表子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_oa_employee_payroll_detail")
public class PayrollDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="payroll_id")
    private Long payrollId; // 工资表主表id
    @TableField(value="dept_id")
    private Long deptId; // 部门ID
    @TableField(value="dept_name")
    private String deptName; // 部门
    @TableField(value="post_id")
    private Long postId; // 岗位ID
    @TableField(value="post_name")
    private String postName; // 岗位
    @TableField(value="source_id")
    private Long sourceId; // 来源id
    @TableField(value="employee_id")
    private Long employeeId; // 员工名称
    @TableField(value="name")
    private String name; // 姓名
    @TableField(value="id_card")
    private String idCard; // 身份证号
    @TableField(value="salary_time")
    private BigDecimal salaryTime; // 计薪工时
    @TableField(value="basic_salary")
    private BigDecimal basicSalary; // 基本薪资
    @TableField(value="post_salary")
    private BigDecimal postSalary; // 岗位薪资
    @TableField(value="level_salary")
    private BigDecimal levelSalary; // 层级薪资
    @TableField(value="educated_salary")
    private BigDecimal educatedSalary; // 学历津贴
    @TableField(value="sport_salary")
    private BigDecimal sportSalary; // 交通补助
    @TableField(value="year_salary")
    private BigDecimal yearSalary; // 司龄津贴
    @TableField(value="attendance_deduct")
    private BigDecimal attendanceDeduct; // 考勤扣款
    @TableField(value="other_pay_mny")
    private BigDecimal otherPayMny; // 其他应付款
    @TableField(value="other_deduct_mny")
    private BigDecimal otherDeductMny; // 其他扣款
    @TableField(value="salary_mny")
    private BigDecimal salaryMny; // 应发工资
    @TableField(value="actual_salary_mny")
    private BigDecimal actualSalaryMny; // 实发工资
    @TableField(value="endownment_person_percent")
    private BigDecimal endownmentPersonMny; // 养老保险
    @TableField(value="unemployee_person_mny")
    private BigDecimal unemployeePersonMny; // 失业保险
    @TableField(value="base_medical_person_mny")
    private BigDecimal baseMedicalPersonMny; // 基本医疗
    @TableField(value="rank")
    private Integer rank; // 职级
    @TableField(value="rank_name")
    private String rankName; // 职级
    @TableField(value="into_date")
    private Date intoDate; // 入职日期
    @TableField(value="formal_date")
    private Date formalDate; // 转正日期
    @TableField(value="payroll_date")
    private Date payrollDate; // 工资单日期
    @TableField(value="detail_memo")
    private String detailMemo; // 备注
    
    
    

    public Long getPayrollId() {
        return payrollId;
    }

    public void setPayrollId(Long payrollId) {
        this.payrollId = payrollId;
    }
    public Long getDeptId() {
        return deptId;
    }

    public void setDeptId(Long deptId) {
        this.deptId = deptId;
    }
    public String getDeptName() {
        return deptName;
    }

    public void setDeptName(String deptName) {
        this.deptName = deptName;
    }
    public Long getPostId() {
        return postId;
    }

    public void setPostId(Long postId) {
        this.postId = postId;
    }
    public String getPostName() {
        return postName;
    }

    public void setPostName(String postName) {
        this.postName = postName;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public String getIdCard() {
        return idCard;
    }

    public void setIdCard(String idCard) {
        this.idCard = idCard;
    }
    public BigDecimal getSalaryTime() {
        return salaryTime;
    }

    public void setSalaryTime(BigDecimal salaryTime) {
        this.salaryTime = salaryTime;
    }
    public BigDecimal getBasicSalary() {
        return basicSalary;
    }

    public void setBasicSalary(BigDecimal basicSalary) {
        this.basicSalary = basicSalary;
    }
    public BigDecimal getPostSalary() {
        return postSalary;
    }

    public void setPostSalary(BigDecimal postSalary) {
        this.postSalary = postSalary;
    }
    public BigDecimal getLevelSalary() {
        return levelSalary;
    }

    public void setLevelSalary(BigDecimal levelSalary) {
        this.levelSalary = levelSalary;
    }
    public BigDecimal getEducatedSalary() {
        return educatedSalary;
    }

    public void setEducatedSalary(BigDecimal educatedSalary) {
        this.educatedSalary = educatedSalary;
    }
    public BigDecimal getSportSalary() {
        return sportSalary;
    }

    public void setSportSalary(BigDecimal sportSalary) {
        this.sportSalary = sportSalary;
    }
    public BigDecimal getYearSalary() {
        return yearSalary;
    }

    public void setYearSalary(BigDecimal yearSalary) {
        this.yearSalary = yearSalary;
    }
    public BigDecimal getAttendanceDeduct() {
        return attendanceDeduct;
    }

    public void setAttendanceDeduct(BigDecimal attendanceDeduct) {
        this.attendanceDeduct = attendanceDeduct;
    }
    public BigDecimal getOtherPayMny() {
        return otherPayMny;
    }

    public void setOtherPayMny(BigDecimal otherPayMny) {
        this.otherPayMny = otherPayMny;
    }
    public BigDecimal getOtherDeductMny() {
        return otherDeductMny;
    }

    public void setOtherDeductMny(BigDecimal otherDeductMny) {
        this.otherDeductMny = otherDeductMny;
    }
    public BigDecimal getSalaryMny() {
        return salaryMny;
    }

    public void setSalaryMny(BigDecimal salaryMny) {
        this.salaryMny = salaryMny;
    }
    public BigDecimal getActualSalaryMny() {
        return actualSalaryMny;
    }

    public void setActualSalaryMny(BigDecimal actualSalaryMny) {
        this.actualSalaryMny = actualSalaryMny;
    }

    public BigDecimal getEndownmentPersonMny() {
        return endownmentPersonMny;
    }

    public void setEndownmentPersonMny(BigDecimal endownmentPersonMny) {
        this.endownmentPersonMny = endownmentPersonMny;
    }

    public BigDecimal getUnemployeePersonMny() {
        return unemployeePersonMny;
    }

    public void setUnemployeePersonMny(BigDecimal unemployeePersonMny) {
        this.unemployeePersonMny = unemployeePersonMny;
    }
    public BigDecimal getBaseMedicalPersonMny() {
        return baseMedicalPersonMny;
    }

    public void setBaseMedicalPersonMny(BigDecimal baseMedicalPersonMny) {
        this.baseMedicalPersonMny = baseMedicalPersonMny;
    }
    public Integer getRank() {
        return rank;
    }

    public void setRank(Integer rank) {
        this.rank = rank;
    }
    public String getRankName() {
        return rankName;
    }

    public void setRankName(String rankName) {
        this.rankName = rankName;
    }
    public Date getIntoDate() {
        return intoDate;
    }

    public void setIntoDate(Date intoDate) {
        this.intoDate = intoDate;
    }
    public Date getFormalDate() {
        return formalDate;
    }

    public void setFormalDate(Date formalDate) {
        this.formalDate = formalDate;
    }
    public Date getPayrollDate() {
        return payrollDate;
    }

    public void setPayrollDate(Date payrollDate) {
        this.payrollDate = payrollDate;
    }
    public String getDetailMemo() {
        return detailMemo;
    }

    public void setDetailMemo(String detailMemo) {
        this.detailMemo = detailMemo;
    }
    
}
